(require 'package)
(add-to-list 'package-archives '("melpa" . "https://melpa.org/packages/") t)
;; Comment/uncomment this line to enable MELPA Stable if desired.  See `package-archive-priorities`
;; and `package-pinned-packages`. Most users will not need or want to do this.
;;(add-to-list 'package-archives '("melpa-stable" . "https://stable.melpa.org/packages/") t)
;;(package-initialize)

(setq package-install-upgrade-built-in t)

(use-package company
	     :ensure t
	     :config
	     (setq company-idle-delay 0.2)
	     (setq company-tooltip-align-annotations t)
	     (setq company-backends (delete 'company-clang company-backends))
	     (setq company-minimum-prefix-length 1))

(with-eval-after-load 'company
  (add-hook 'c++mode-hook 'company-mode)
  (add-hook 'c-mode-hook 'company-mode)
  (add-hook 'java-mode-hook 'company-mode))

(global-set-key (kbd "C-c y") 'company-yasnippet)

(add-hook 'prog-mode-hook 'display-line-numbers-mode)

(add-hook 'prog-mode-hook 'yas-minor-mode)

(use-package which-key
  :ensure t
  :init
  (which-key-setup-minibuffer)
  (which-key-mode))

;; Ajustes de dired-sidebar
(use-package dired-sidebar
  :ensure t
  :defer t
  :commands (dired-sidebar-toggle-sidebar)
  :init
  (setq dired-sidebar-theme 'nerd)
  (setq dired-sidebar-use-term-integration t)
  (setq dired-sidebar-use-custom-font nil))

(use-package dired-git
  :ensure t)

(use-package nerd-icons-dired
  :hook
  (dired-mode . nerd-icons-dired-mode))

(use-package nerd-icons-ibuffer
  :ensure t
  :hook (ibuffer-mode . nerd-icons-ibuffer-mode))


(use-package ibuffer-sidebar
  :load-path "~/.emacs.d/ibuffer-sidebar"
  :ensure nil
  :commands (ibuffer-sidebar-toggle-sidebar)
  :config
  (setq ibuffer-sidebar-use-custom-font t)
  )

 


(global-set-key (kbd "C-c s") 'dired-sidebar-toggle-sidebar)
(global-eldoc-mode t)

(custom-set-faces
 ;; custom-set-faces was added by Custom.
 ;; If you edit it by hand, you could mess it up, so be careful.
 ;; Your init file should contain only one such instance.
 ;; If there is more than one, they won't work right.
 '(default ((t (:inherit nil :stipple nil :background unspecified :foreground unspecified :inverse-video nil :box nil :strike-through nil :overline nil :underline nil :slant normal :weight normal :height 120 :width normal :foundry "DAMA" :family "Ubuntu Mono")))))


(use-package heaven-and-hell
:ensure t
:init
(setq heaven-and-hell-theme-type 'dark) ;; usa el oscuro por defecto
(setq heaven-and-hell-themes
      '((light . jsc-light2)
        (dark . dracula))) ;; Se puede sustituir por (dark . (tsdh-dark wombat))
;; Opcional, carga el tema sin pedir confirmación
(setq heaven-and-hell-load-theme-no-confirm t)
:hook ((after-init . heaven-and-hell-init-hook)))
;; configuración de la tecla de cambio
(global-set-key (kbd "<f6>") 'heaven-and-hell-toggle-theme)

;; Mejorando la visualización de la línea de estado
(use-package powerline
  :ensure t
  :config
  (powerline-default-theme)
  (setq powerline-default-separator 'rounded))

(defun ajuste-powerline-theme ()
  "Hace un reset de la powerline tras cambiar el tema."
  (interactive)
  (heaven-and-hell-toggle-theme)
  (powerline-reset))

(defun ajuste-powerline-default-theme ()
  "Hace un reset de la powerline tras cambiar al tema por defecto."
  (interactive)
  (heaven-and-hell-load-default-theme)
  (powerline-reset))

(global-set-key (kbd "C-c <f6>") 'ajuste-powerline-default-theme)
(global-set-key (kbd "<f6>")     'ajuste-powerline-theme)


;; vterm vterm-togle
(global-set-key [C-f2] 'vterm-toggle)
(global-set-key [f5] (quote speedbar-get-focus))

(add-hook 'prog-mode-hook 'hs-minor-mode) ; para poder plegar funciones
(add-hook 'prog-mode-hook 'hl-line-mode)

(use-package markdown-mode
  :ensure t)
(add-to-list 'auto-mode-alist '("\\.md\\'" . markdown-mode))


(use-package company-box
  :ensure t
  :defer t
  :after company
  :hook 'company-mode-hook 'company-box-mode)

(global-set-key (kbd "<S-return>") 'hs-toggle-hiding)
(global-set-key (kbd "<M-return>") 'hs-show-block)

(use-package rainbow-delimiters
  :ensure t
  :defer t
  :hook ((prog-mode . rainbow-delimiters-mode)))

(defun my-tabbar-buffer-groups () ;; customize to show all normal files in one group
      "Returns the name of the tab group names the current buffer belongs to.
    There are two groups: Emacs buffers (those whose name starts with '*', plus
    dired buffers), and the rest.  This works at least with Emacs v24.2 using
    tabbar.el v1.7."
      (list (cond ((string-equal "*" (substring (buffer-name) 0 1)) "emacs")
                  ((eq major-mode 'dired-mode) "emacs")
		  ((eq major-mode 'dired-sidebar-mode) "emacs")
                  (t "user"))))
    (setq tabbar-buffer-groups-function 'my-tabbar-buffer-groups)

(provide 'init)
;;; init.el ends here
